@@ -5,9 +5,6 @@ from django_json_widget.widgets import JSONEditorWidget
 from polymorphic.admin import PolymorphicChildModelAdmin, PolymorphicParentModelAdmin
 
 from nwon_django_toolbox.fields import PydanticJsonField
-from nwon_django_toolbox.fields.encrypted_text_field.encrypted_text_field import (
-    EncryptedTextField,
-)
 
 
 class PolymorphicParentModelAdminWithJsonEditor(PolymorphicParentModelAdmin):
@@ -39,9 +36,6 @@ class ModelAdminWithJsonEditorReadOnly(admin.ModelAdmin):
         PydanticJsonField: {
             "widget": JSONEditorWidget(options={"mode": "view", "modes": ["view"]})
         },
-        EncryptedTextField: {
-            "widget": forms.PasswordInput(render_value=False),
-        },
     }
 
 
