@@ -1,3 +1,6 @@
+# pylint: disable=unused-argument
+
+
 class ReadOnlyAdminMixin:
     def has_add_permission(self, request):
         return False
@@ -9,7 +12,7 @@ class ReadOnlyAdminMixin:
         return False
 
 
-class DeletaAndReadOnlyAdminMixin:
+class DeleteAndReadOnlyAdminMixin:
     def has_add_permission(self, request):
         return False
 
