@@ -1,4 +1,3 @@
-from nwon_django_toolbox.fields.encrypted_text_field import EncryptedTextField
 from nwon_django_toolbox.fields.pydantic_json_field import (
     ModelSerializerWithPydantic,
     PydanticJsonField,
@@ -10,7 +9,6 @@ from nwon_django_toolbox.fields.serializer_choice_field_for_polymorphic_ctype_id
 
 __all__ = [
     "serializer_choice_field_for_polymorphic_ctype_id",
-    "EncryptedTextField",
     "PydanticJsonFieldSerializer",
     "PydanticJsonField",
     "ModelSerializerWithPydantic",
